@@ -37,6 +37,14 @@ private slots:
     void requestFailedWithFacebookError ( const FBError& aError );
     void requestFailedWithNetworkError( QNetworkReply::NetworkError code );
 
+#if defined(Q_OS_SYMBIAN)
+	/* This is a workaround a Qt bug which is very visible on symbian or any touch device without a keyboard.
+	Virtual keyboard wont be shown for <input type="email">, so we replace type="email" with type="text" in this workaround..
+	This will be fixed in Qt 4.7.0, more info on this: http://code.google.com/p/qfacebookconnect/issues/detail?id=9 */
+	void loadFinished ( bool ok );
+	/* End work around */
+#endif
+
 public:
     FBLoginDialog(FBSession* aSession);
     FBLoginDialog();
